#!BPY

# Version 1.0 from 2010-07-27 (use the newest one if you have multiple, they're downward compatible)

#name of the directory containing base / the mod folders, e.g. gamedata for Jedi Academy (in lowercase)
DIRNAME = "gamedata"

import os

# returns: end of the gamepath (".../DIRNAME/") or -1
def GetGamepathEnd(full_path):
	return full_path.lower().replace( '\\', '/' ).find('/' + DIRNAME + '/') + len(DIRNAME) + 2

#returns: end of the next folder in the gamepath (".../DIRNAME/.../") or -1
def GetGamepathSubfolderEnd(full_path):
	pos1 = GetGamepathEnd(full_path)
	if pos1 == -1:
		return -1
	#when searching we don't care about case or the separator.
	searchme = full_path.lower().replace( '\\', '/' )[pos1:]
	pos2 = searchme.find('/')
	if pos2 == -1:
		return -1
	return pos1+pos2+1

# returns: (dirname, success), where dirname is the folder next to DIRNAME, e.g. "Base" for ".../GameData/Base/..."
def GetGamepathSubfolder(full_path):
	pos1 = GetGamepathEnd(full_path)
	if pos1 == -1:
		return "", False
	pos2 = GetGamepathSubfolderEnd(full_path)
	if pos2 == -1:
		return "", False
	return full_path[pos1:pos2-1], True

# returns: (gamepath, success) where gamepath includes DIRNAME and the next dir, e.g. '.../GameData/.../'
def GetGamepathAndSubfolder(full_path):
	pos = GetGamepathSubfolderEnd(full_path)
	if pos == -1:
		return "", False
	return full_path[0:pos], True

# returns: (gamepath, success) where gamepath includes DIRNAME, e.g. '.../GameData/'
def GetGamepath(full_path):
	pos = GetGamepathEnd(full_path)
	if pos == -1:
		return "", False
	return full_path[0:pos], True

# returns: (relative_path, success), i.e. strips ".../GameData/.../"
def StripGamepathAndSubfolder(full_path):
	pos = GetGamepathSubfolderEnd(full_path)
	if pos == -1:
		return full_path, False
	return full_path[pos:], True

# strips file type extension
def StripExtension(path):
	pos_dot = path.rfind(".")
	path_nice = path.replace("\\", "7")
	pos_slash = path_nice.rfind("/")
	if pos_dot == -1 or pos_dot < pos_slash:
		return path
	return path[0:pos_dot]

# returns the file type extension (or "")
def GetExtension(path):
	pos_dot = path.rfind(".")
	path_nice = path.replace("\\", "7")
	pos_slash = path_nice.rfind("/")
	if pos_dot == -1 or pos_dot < pos_slash:
		return ""
	return path[pos_dot+1:]

# returns the full path to this file, if found, or "", looking in both the mod's folder and base.
def FindFile(gamepath, subfolder, relative_path):
	if os.path.exists(gamepath+subfolder+"/"+relative_path):
		return gamepath+subfolder+"/"+relative_path
	if subfolder.lower() != "base" and os.path.exists(gamepath+"base/"+relative_path):
		return gamepath+"base/"+relative_path
	return ""

def FindTexture(gamepath, subfolder, relative_path):
	#first try the normal name
	name = relative_path
	#see if it's valid as it is
	file = FindFile(gamepath, subfolder, name)
	if file != "":
		return file
	# we do this twice: once normal, once without the extension
	for i in range(2):
		#try adding all kinds of extensions
		for ext in (".jpg", ".tga", ".png"):
			file = FindFile(gamepath, subfolder, name+ext)
			if file != "":
				return file
		#then try it without the extension, if there was any
		name2 = StripExtension(name)
		if name2 == name:
			#if there was none, we're done here.
			break;
		name = name2
	return ""